@@ -307,16 +307,16 @@ class DistributedScheduler(object):
                 raise IOError("Could not get valid IP Address")
             obj.close()
             self.logger.debug("Current public ip: {ip}".format(ip=self.my_ip))
+
+            if self.old_ip != self.my_ip:
+                self.logger.info("Changed Public IP: {old} -> {new}".format(
+                    old=self.old_ip, new=self.my_ip))
+                if self.old_ip is not None and self.my_ip != '52.28.30.162':
+                    self.signals.send_catch_log_deferred(signal=bhf_signals.ip_changed)
         except IOError:
             self.logger.error("Could not reach out to get public ip")
             pass
 
-        if self.old_ip != self.my_ip:
-            self.logger.info("Changed Public IP: {old} -> {new}".format(
-                old=self.old_ip, new=self.my_ip))
-            if self.old_ip is not None:
-                self.signals.send_catch_log_deferred(signal=bhf_signals.ip_changed)
-
     def report_self(self):
         '''
         Reports the crawler uuid to redis
